@echo off
setlocal EnableDelayedExpansion
REM  Licensed Materials - Property of IBM
REM  Restricted Materials of IBM
REM 
REM  Copyright IBM Corp. 2010 All Rights Reserved.
REM  US Government Users Restricted Rights - Use, duplication or
REM  disclosure restricted by GSA ADP Schedule Contract with
REM  IBM Corp.
REM 
REM  Description: Application Support Installer wrapper script
REM
REM  Parameters:
REM    -h {full path to ITM home}
REM    -silent
REM    -r {response file}
REM    -j {JAVAHOME}
REM
REM  Returns:
REM    ERRORLEVEL=0 - successful
REM    ERRORLEVEL=1 - failed
REM ======================================================


REM parse the input parameters
if not (%8)==() goto usage
:getparm
if /I "%1"=="-silent" goto silent
if "%1"=="-r" goto response
if "%1"=="-h" goto itmhome
if "%1"=="-j" goto javahome
if not (%1)==() goto usage
goto doneparm
:silent
set SILENT=%1
shift
goto getparm
:itmhome
if (%2)==() goto usage
set CANDLE_HOME=%2
if not exist %CANDLE_HOME%\tmaitm6 goto failITMHome
shift
shift
echo %CANDLE_HOME% | find """" >NUL
set EL=%ERRORLEVEL%
if %EL% EQU 1 (
  set CANDLE_HOME_TMP1=X%CANDLE_HOME%X
  set CANDLE_HOME_TMP="%CANDLE_HOME_TMP1:~1,-1%"
)
if not %EL% EQU 1 (
  set CANDLE_HOME_TMP=%CANDLE_HOME%
)
goto getparm
:response
if (%2)==() goto usage
set RESPONSE=%2
if not exist %RESPONSE% goto failResponse
shift
shift
goto getparm
:javahome
if (%2)==() goto usage
set JAVAHOME=%2
if not exist %JAVAHOME%\bin\java.exe goto failJavahome
set JAVAHOME=%JAVAHOME:"=%
shift
shift
goto getparm
:doneparm

REM ask for the ITM install directory if not in the environment
echo %CANDLE_HOME% | find """" >NUL
set EL=%ERRORLEVEL%
if %ERRORLEVEL% EQU 1 set CANDLE_HOME="%CANDLE_HOME%"
if not exist %CANDLE_HOME%\tmaitm6 (
if /I "%SILENT%" == "-silent" goto failITMHome
:chkagain
  SET "CANDLE_HOME="
  SET /P CANDLE_HOME=Enter the path of the IBM Tivoli Monitoring directory or q to quit:
)
if X%CANDLE_HOME% == Xq goto end
set CANDLE_HOME=%CANDLE_HOME:"=%
if not exist "%CANDLE_HOME%"\tmaitm6 (
  echo ERROR: "%CANDLE_HOME%"\tmaitm6 was not found...
  goto chkagain
)

if not (%RESPONSE%)==() goto skipresp
REM parse the response.txt file and update the CANDLE_HOME and patch install path
if exist "%CD%"\response.tmp erase "%CD%"\response.tmp
for /f "tokens=*" %%a in ('type "%CD%"\response.txt') do call :PARSELINE "%%a"
set RESPONSE="%CD%"\response.tmp
:skipresp

if X"%JAVAHOME%" == X"" (
  REM Find JAVAHOME
  @FOR /F "tokens=*" %%i IN ('cscript /nologo "%CANDLE_HOME%"\InstallITM\CandleGetJavaHome.vbs') DO set JAVAHOME=%%i
)
if not exist "%JAVAHOME%"\bin\java.exe goto failJavahome
if /I "%SILENT%" == "-silent" goto silentInstall

:performInstall
SET ANS=
SET /P ANS=Are you sure you want to install the patch using JAVAHOME=%JAVAHOME%, enter (y/n):
if not "%ANS%" == "y" goto end

echo Executing: %JAVAHOME%\bin\java.exe -jar setup.jar
set JAVAHOME=%JAVAHOME:"=%
"%JAVAHOME%"\bin\java.exe -jar setup.jar
echo Trace log location: %TEMP%
goto end

:silentInstall
echo Executing: %JAVAHOME%\bin\java.exe -jar setup.jar -silent -options %RESPONSE%
set JAVAHOME=%JAVAHOME:"=%
"%JAVAHOME%"\bin\java.exe -jar setup.jar -silent -options %RESPONSE%
echo Trace log location: %TEMP%
goto end

:failITMHome
set ERRORLEVEL=1
echo ITM home(CANDLE_HOME) is not a valid path, the installation has been aborted...
goto end

:failJavahome
set ERRORLEVEL=1
echo JAVAHOME is not a valid path to %JAVAHOME%\bin\java.exe, the installation has been aborted...
goto end

:failResponse
set ERRORLEVEL=1
echo response file: %RESPONSE% not found, the installation has been aborted...
goto end

:usage
set ERRORLEVEL=1
echo.
echo Usage: 
echo   itmasi.bat [-h {ITM home}] [-silent] [-r {response file}] [-j {JAVAHOME}]"
echo.
echo where
echo. 
echo -h       Specifies the ITM installation directory, uses
echo          CANDLE_HOME if -h not specified.
echo -silent  Specifies silent install using a response file.
echo -r       Specifies a fully qualified path to a response file,
echo          uses response.txt if -r not specified.
echo -j       Specifies the JAVAHOME directory, uses
echo          JAVAHOME if not specified.
echo.
echo Default trace log location: %TEMP%
goto end

:PARSELINE

set line=%~1
if "%line%"=="" (
  echo.>>"%CD%"\response.tmp
  goto :EOF
)
echo %line% | find "-W Directories.itmhome=" >NUL
if %ERRORLEVEL% EQU 0 (
  echo -W Directories.itmhome=%CANDLE_HOME_TMP% >> "%CD%"\response.tmp
  goto :EOF
)
echo %line% | find "-W Directories.mediaLocation=" >NUL
if %ERRORLEVEL% EQU 0 (
  echo -W Directories.mediaLocation="%CD%" >> "%CD%"\response.tmp
  goto :EOF
)
echo %line% >> "%CD%"\response.tmp
goto :EOF

:end

endlocal
